gedidb.GEDIGranule
==================

.. currentmodule:: gedidb

.. autoclass:: GEDIGranule

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GEDIGranule.__init__
      ~GEDIGranule.parse_granules
      ~GEDIGranule.process_granule
   
   

   
   
   